@@ -3,10 +3,9 @@ import asyncio
 import signal
 import threading
 
-import uvloop
-
-from scaled.scheduler.router import Router
+from scaled.scheduler.main import Scheduler
 from scaled.scheduler.worker_manager.vanilla import AllocatorType
+from scaled.utility.event_loop import EventLoopType, register_event_loop
 from scaled.utility.zmq_config import ZMQConfig
 from scaled.utility.logging.utility import setup_logger
 
@@ -31,6 +30,9 @@ def get_args():
         choices={t for t in AllocatorType},
         help="specify allocator type",
     )
+    parser.add_argument(
+        "--event-loop", default="builtin", choices=EventLoopType.allowed_types(), help="select event loop type"
+    )
     parser.add_argument("address", type=ZMQConfig.from_string, help="scheduler address to connect to")
 
     return parser.parse_args()
@@ -42,15 +44,15 @@ def main():
 
     __register_signal()
 
-    router = Router(
+    scheduler = Scheduler(
         address=args.address,
         stop_event=stop_event,
         allocator_type=args.allocator_type,
         worker_timeout_seconds=args.worker_timeout_seconds,
         function_timeout_seconds=args.function_timeout_seconds,
     )
-    uvloop.install()
-    asyncio.run(router.loop())
+    register_event_loop(args.event_loop)
+    asyncio.run(scheduler.loop())
 
 
 def __register_signal():
@@ -59,4 +61,5 @@ def __register_signal():
 
 
 def __handle_signal(*args):
+    assert args is not None
     stop_event.set()
